@@ -1,67 +1,18 @@
-import copy
 import functools
 import json
 import logging
-import ujson
-from urllib.parse import urlparse
 import struct
 
 import requests as rq
+import ujson
 
-from .abstract import ConnectIntf, IndexParam, CollectionSchema, PartitionParam
-from .check import is_legal_host, is_legal_port
-from .exceptions import NotConnectError, ParamError
-from .types import Status, IndexType, MetricType
-
-from ..settings import DefaultConfig as config
+from .exceptions import NotConnectError
+from .types import Status
+from .utils import set_uri
 
 logging.getLogger("requests").setLevel(logging.WARNING)
 logging.getLogger("urllib3").setLevel(logging.WARNING)
 
-IndexValue2NameMap = {
-    IndexType.INVALID: "INVALID",
-    IndexType.FLAT: "FLAT",
-    IndexType.IVFLAT: "IVFFLAT",
-    IndexType.IVF_SQ8: "IVFSQ8",
-    IndexType.IVF_SQ8H: "IVFSQ8H",
-    IndexType.IVF_PQ: "IVFPQ",
-    IndexType.RNSG: "RNSG",
-    IndexType.HNSW: "HNSW",
-    IndexType.ANNOY: "ANNOY"
-}
-
-IndexName2ValueMap = {
-    "INVALID": IndexType.INVALID,
-    "FLAT": IndexType.FLAT,
-    "IVFFLAT": IndexType.IVFLAT,
-    "IVFSQ8": IndexType.IVF_SQ8,
-    "IVFSQ8H": IndexType.IVF_SQ8H,
-    "IVFPQ": IndexType.IVF_PQ,
-    "RNSG": IndexType.RNSG,
-    "HNSW": IndexType.HNSW,
-    "ANNOY": IndexType.ANNOY
-}
-
-MetricValue2NameMap = {
-    MetricType.L2: "L2",
-    MetricType.IP: "IP",
-    MetricType.HAMMING: "HAMMING",
-    MetricType.JACCARD: "JACCARD",
-    MetricType.TANIMOTO: "TANIMOTO",
-    MetricType.SUBSTRUCTURE: "SUBSTRUCTURE",
-    MetricType.SUPERSTRUCTURE: "SUPERSTRUCTURE"
-}
-
-MetricName2ValueMap = {
-    "L2": MetricType.L2,
-    "IP": MetricType.IP,
-    "HAMMING": MetricType.HAMMING,
-    "JACCARD": MetricType.JACCARD,
-    "TANIMOTO": MetricType.TANIMOTO,
-    "SUBSTRUCTURE": MetricType.SUBSTRUCTURE,
-    "SUPERSTRUCTURE": MetricType.SUPERSTRUCTURE
-}
-
 
 LOGGER = logging.getLogger(__name__)
 
@@ -85,14 +36,14 @@ def handle_error(returns=tuple()):
     return decorator
 
 
-class HttpHandler(ConnectIntf):
+class HttpHandler:
 
     def __init__(self, host=None, port=None, **kwargs):
         self._status = None
 
         _uri = kwargs.get("uri", None)
 
-        self._uri = (host or port or _uri) and self._set_uri(host, port, uri=_uri)
+        self._uri = (host or port or _uri) and set_uri(uri=_uri)
         self._max_retry = kwargs.get("max_retry", 3)
 
     def __enter__(self):
@@ -103,58 +54,33 @@ class HttpHandler(ConnectIntf):
     def __exit__(self, exc_type, exc_val, exc_tb):
         pass
 
-    def _set_uri(self, host, port, uri):
-        """
-        Set server network address
-
-        :raises: ParamError
-
-        """
-        if host is not None:
-            _port = port if port is not None else config.HTTP_PORT
-            _host = host
-        elif port is None:
-            try:
-                _uri = urlparse(uri) if uri else urlparse(config.HTTP_URI)
-                _host = _uri.hostname
-                _port = _uri.port
-            except (AttributeError, ValueError, TypeError) as e:
-                raise ParamError("uri is illegal: {}".format(e))
-        else:
-            raise ParamError("Param is not complete. Please invoke as follow:\n"
-                             "\t(host = ${HOST}, port = ${PORT})\n"
-                             "\t(uri = ${URI})\n")
-
-        if not is_legal_host(_host) or not is_legal_port(_port):
-            raise ParamError("host or port is illeagl")
-
-        return "http://{}:{}".format(str(_host), str(_port))
-
     @property
     def status(self):
         return self._status
 
     def ping(self, timeout=10):
         if self._uri is None:
-            self._uri = self._set_uri(None, None, None)
-        logging.info("Connecting server {}".format(self._uri))
+            self._uri = set_uri(None)
+        logging.info("Connecting server {}", self._uri)
         retry = self._max_retry
         try:
             while retry > 0:
                 try:
-                    response = rq.get(self._uri + "/state", timeout=timeout)
+                    rq.get(self._uri + "/state", timeout=timeout)
                     return True
-                except:
+                except (rq.exceptions.Timeout,
+                        rq.exceptions.TooManyRedirects,
+                        rq.exceptions.RequestException):
                     retry -= 1
                     if retry > 0:
                         continue
-                    else:
-                        raise
+
+                    raise
         except:
-            LOGGER.error("Cannot connect server {}".format(self._uri))
+            LOGGER.error("Cannot connect server {}", self._uri)
             raise NotConnectError("Cannot get server status")
 
-        LOGGER.info("Connected server {}".format(self._uri))
+        LOGGER.info("Connected server {}", self._uri)
         # try:
         #     js = response.json()
         #     return Status(js["code"], js["message"])
@@ -168,7 +94,7 @@ class HttpHandler(ConnectIntf):
 
     def connect(self, host, port, uri, timeout):
         if self.connected():
-            return Status(message="You have already connected {} !".format(self._uri),
+            return Status(message=f"You have already connected {self._uri} !",
                           code=Status.CONNECT_FAILED)
 
         if (host or port or uri) or not self._uri:
@@ -205,11 +131,11 @@ class HttpHandler(ConnectIntf):
             if response.status_code == 200:
                 js = response.json()
                 return Status(), js["message"]
-            elif response.status_code == 400:
+            if response.status_code == 400:
                 js = response.json()
                 return Status(js["code"], js["message"]), None
-            else:
-                return Status(Status.UNEXPECTED_ERROR, response.reason)
+
+            return Status(Status.UNEXPECTED_ERROR, response.reason)
 
     def _get_config(self, cmd, timeout):
         if cmd.startswith("get_config"):
@@ -222,21 +148,24 @@ class HttpHandler(ConnectIntf):
                 js = response.json()
                 rc_parent = js.get(config_node[0], None)
                 if rc_parent is None:
-                    return Status(Status.UNEXPECTED_ERROR, "Config {} not supported".format(cmd_node[1]))
+                    return Status(Status.UNEXPECTED_ERROR,
+                                  "Config {} not supported".format(cmd_node[1]))
                 rc_child = rc_parent.get(config_node[1], None)
                 if rc_child is None:
-                    return Status(Status.UNEXPECTED_ERROR, "Config {} not supported".format(cmd_node[1]))
+                    return Status(Status.UNEXPECTED_ERROR,
+                                  "Config {} not supported".format(cmd_node[1]))
 
                 return Status(), rc_child
                 # return Status(), js["message"]
-            elif response.status_code == 400:
+
+            if response.status_code == 400:
                 js = response.json()
                 return Status(js["code"], js["message"]), None
-            else:
-                return Status(Status.UNEXPECTED_ERROR, response.reason)
+
+            return Status(Status.UNEXPECTED_ERROR, response.reason)
 
     @handle_error(returns=(None,))
-    def _cmd(self, cmd, timeout=10):
+    def cmd(self, cmd, timeout=10):
         if cmd.startswith("get_config"):
             return self._get_config(cmd, timeout)
         if cmd.startswith("set_config"):
@@ -259,14 +188,13 @@ class HttpHandler(ConnectIntf):
         return self._cmd("status", timeout)
 
     @handle_error()
-    def create_collection(self, collection_name, dimension, index_file_size, metric_type, params=None, timeout=10):
-        metric = MetricValue2NameMap.get(metric_type, None)
-
+    def create_collection(self, collection_name, dimension, index_file_size,
+                          metric_type, params=None, timeout=10):
         table_param = {
             "collection_name": collection_name,
             "dimension": dimension,
             "index_file_size": index_file_size,
-            "metric_type": metric
+            "metric_type": metric_type
         }
 
         data = ujson.dumps(table_param)
@@ -278,7 +206,7 @@ class HttpHandler(ConnectIntf):
                 return Status(message='Create table successfully!')
 
             js = response.json()
-            return Status(Status(js["code"], js["message"]))
+            return Status(js["code"], js["message"])
         except Exception as e:
             return Status(Status.UNEXPECTED_ERROR, message=str(e))
 
@@ -294,7 +222,7 @@ class HttpHandler(ConnectIntf):
                 return Status(), False
 
             js = response.json()
-            return Status(Status(js["code"], js["message"])), False
+            return Status(js["code"], js["message"]), False
         except Exception as e:
             return Status(Status.UNEXPECTED_ERROR, message=str(e))
 
@@ -309,9 +237,9 @@ class HttpHandler(ConnectIntf):
             if response.status_code == 200:
                 return Status(), js["count"]
 
-            return Status(Status(js["code"], js["message"])), None
+            return Status(js["code"], js["message"]), None
         except Exception as e:
-            return Status(Status.UNEXPECTED_ERROR, message=str(e)), None
+            return Status(1, message=str(e)), None
 
     @handle_error(returns=(None,))
     def describe_collection(self, table_name, timeout):
@@ -320,22 +248,13 @@ class HttpHandler(ConnectIntf):
         response = rq.get(url, timeout=timeout)
 
         if response.status_code >= 500:
-            return Status(Status.UNEXPECTED_ERROR, response.reason), None
+            return Status(1, response.reason), None
 
         js = response.json()
         if response.status_code == 200:
-            metric_map = dict()
-            _ = [metric_map.update({i.name: i.value}) for i in MetricType if i.value > 0]
+            return Status(message='Describe table successfully!'), js
 
-            table = CollectionSchema(
-                collection_name=js["collection_name"],
-                dimension=js["dimension"],
-                index_file_size=js["index_file_size"],
-                metric_type=metric_map[js["metric_type"]])
-
-            return Status(message='Describe table successfully!'), table
-
-        return Status(Status(js["code"], js["message"])), None
+        return Status(js["code"], js["message"]), None
 
     @handle_error(returns=([],))
     def show_collections(self, timeout):
@@ -343,14 +262,14 @@ class HttpHandler(ConnectIntf):
 
         response = rq.get(url, params={"offset": 0, "page_size": 0}, timeout=timeout)
         if response.status_code != 200:
-            return Status(Status.UNEXPECTED_ERROR, response.reason), []
+            return Status(1, response.reason), []
 
         js = response.json()
         count = js["count"]
 
         response = rq.get(url, params={"offset": 0, "page_size": count}, timeout=timeout)
         if response.status_code != 200:
-            return Status(Status.UNEXPECTED_ERROR, response.reason), []
+            return Status(1, response.reason), []
 
         tables = []
         js = response.json()
@@ -369,13 +288,13 @@ class HttpHandler(ConnectIntf):
             return Status(), response.json()
 
         if response.status_code == 404:
-            return Status(Status.COLLECTION_NOT_EXISTS, "Collection not found"), None
+            return Status(1, "Collection not found"), None
 
         if response.text:
             result = response.json()
-            return Status(Status(result["code"], result["message"])), None
+            return Status(result["code"], result["message"]), None
 
-        return Status(Status.UNEXPECTED_ERROR, "Response is empty"), None
+        return Status(1, "Response is empty"), None
 
     @handle_error()
     def preload_collection(self, table_name, timeout):
@@ -407,7 +326,7 @@ class HttpHandler(ConnectIntf):
         return Status(js["code"], js["message"])
 
     @handle_error(returns=([],))
-    def insert(self, table_name, records, ids, partition_tag, params, timeout, **kwargs):
+    def bulk_insert(self, table_name, records, ids, partition_tag, params, timeout, **kwargs):
         url = self._uri + "/collections/{}/vectors".format(table_name)
 
         data_dict = dict()
@@ -433,7 +352,7 @@ class HttpHandler(ConnectIntf):
             ids = [int(item) for item in list(js["ids"])]
             return Status(message='Add vectors successfully!'), ids
 
-        return Status(Status(js["code"], js["message"])), []
+        return Status(js["code"], js["message"]), []
 
     @handle_error(returns=(None,))
     def get_vectors_by_ids(self, collection_name, ids, timeout):
@@ -442,7 +361,7 @@ class HttpHandler(ConnectIntf):
             return status, None
         metric = table_schema.metric_type
 
-        bin_vector = metric in list(MetricType.__members__.values())[3:]
+        # bin_vector = metric in list(MetricType.__members__.values())[3:]
 
         url = self._uri + "/collections/{}/vectors".format(collection_name)
         ids_list = list(map(str, ids))
@@ -459,7 +378,7 @@ class HttpHandler(ConnectIntf):
             vector_results = []
             for vector_res in vectors:
                 vector = list(vector_res["vector"])
-                if bin_vector:
+                if metric.startswith("BIN"):
                     vector_results.append(bytes(vector))
                 else:
                     vector_results.append(vector)
@@ -470,8 +389,8 @@ class HttpHandler(ConnectIntf):
 
     @handle_error(returns=(None,))
     def get_vector_ids(self, table_name, segment_name, timeout):
-        # TODO: here specify page_size hard is stupid, need server support query string 'qll_required'
-        url = self._uri + "/collections/{}/segments/{}/ids?page_size=1000000".format(table_name, segment_name)
+        url = self._uri + \
+              "/collections/{}/segments/{}/ids?page_size=1000000".format(table_name, segment_name)
         response = rq.get(url, timeout=timeout)
         result = response.json()
 
@@ -484,9 +403,8 @@ class HttpHandler(ConnectIntf):
     def create_index(self, table_name, index_type, index_params, timeout):
         url = self._uri + "/collections/{}/indexes".format(table_name)
 
-        index = IndexValue2NameMap.get(index_type)
         request = dict()
-        request["index_type"] = index
+        request["index_type"] = index_type
         request["params"] = index_params
         data = ujson.dumps(request)
         headers = {"Content-Type": "application/json"}
@@ -503,15 +421,14 @@ class HttpHandler(ConnectIntf):
         response = rq.get(url, timeout=timeout)
 
         if response.status_code >= 500:
-            return Status(Status.UNEXPECTED_ERROR,
+            return Status(1,
                           "Unexpected error.\n\tStatus code : {}, reason : {}"
                           .format(response.status_code, response.reason))
 
         js = response.json()
 
         if response.status_code == 200:
-            index_type = IndexName2ValueMap.get(js["index_type"])
-            return Status(), IndexParam(table_name, index_type, js["params"])
+            return Status(), js
 
         return Status(js["code"], js["message"]), None
 
@@ -539,7 +456,7 @@ class HttpHandler(ConnectIntf):
             return Status()
 
         js = response.json()
-        return Status(Status(js["code"], js["message"]))
+        return Status(js["code"], js["message"])
 
     @handle_error(returns=([],))
     def show_partitions(self, table_name, timeout):
@@ -548,19 +465,17 @@ class HttpHandler(ConnectIntf):
 
         response = rq.get(url, params=query_data, timeout=timeout)
         if response.status_code >= 500:
-            return Status(Status.UNEXPECTED_ERROR,
+            return Status(1,
                           "Unexpected error. Status code : 500, reason: {}"
                           .format(response.reason)), None
 
         js = response.json()
         if response.status_code == 200:
-            partition_list = \
-                [PartitionParam(table_name, item["partition_tag"])
-                 for item in js["partitions"]]
+            partition_list = [item["partition_tag"] for item in js["partitions"]]
 
             return Status(), partition_list
 
-        return Status(Status(js["code"], js["message"])), []
+        return Status(js["code"], js["message"]), []
 
     @handle_error(returns=(False,))
     def has_partition(self, collection_name, tag, timeout=30):
@@ -575,7 +490,7 @@ class HttpHandler(ConnectIntf):
             return Status(), False
 
         js = response.json()
-        return Status(Status(js["code"], js["message"])), False
+        return Status(js["code"], js["message"]), False
 
     @handle_error()
     def drop_partition(self, collection_name, partition_tag, timeout=10):
@@ -590,10 +505,11 @@ class HttpHandler(ConnectIntf):
             return Status()
 
         js = response.json()
-        return Status(Status(js["code"], js["message"]))
+        return Status(js["code"], js["message"])
 
     @handle_error(returns=(None,))
-    def search(self, collection_name, top_k, query_records, partition_tags=None, search_params=None, timeout=None, **kwargs):
+    def search(self, collection_name, top_k, query_records, partition_tags=None,
+               search_params=None, timeout=None, **kwargs):
         url = self._uri + "/collections/{}/vectors".format(collection_name)
 
         search_body = dict()
@@ -622,7 +538,8 @@ class HttpHandler(ConnectIntf):
         return Status(js["code"], js["message"]), None
 
     @handle_error(returns=(None,))
-    def search_by_ids(self, collection_name, ids, top_k, partition_tags=None, search_params=None, timeout=None, **kwargs):
+    def search_by_ids(self, collection_name, ids, top_k, partition_tags=None,
+                      search_params=None, timeout=None, **kwargs):
         url = self._uri + "/collections/{}/vectors".format(collection_name)
         body_dict = dict()
         body_dict["topk"] = top_k
@@ -642,10 +559,11 @@ class HttpHandler(ConnectIntf):
             # return Status(), TopKQueryResult2(response)
 
         js = response.json()
-        return Status(Status(js["code"], js["message"])), None
+        return Status(js["code"], js["message"]), None
 
     @handle_error(returns=(None,))
-    def search_in_files(self, collection_name, file_ids, query_records, top_k, search_params, timeout, **kwargs):
+    def search_in_files(self, collection_name, file_ids, query_records,
+                        top_k, search_params, timeout, **kwargs):
         url = self._uri + "/collections/{}/vectors".format(collection_name)
 
         body_dict = dict()
@@ -670,7 +588,7 @@ class HttpHandler(ConnectIntf):
             # return Status(), TopKQueryResult2(response)
 
         js = response.json()
-        return Status(Status(js["code"], js["message"])), None
+        return Status(js["code"], js["message"]), None
 
     @handle_error()
     def delete_by_id(self, table_name, id_array, timeout=None):
