@@ -1,25 +1,25 @@
 # -*- coding: UTF-8 -*-
 
 import logging
-import os
 import queue
 import threading
 import time
 from collections import defaultdict
 
 from . import __version__
-from .grpc_handler import GrpcHandler
+from .grpc_client import grpc_handler
 from .http_handler import HttpHandler
-from milvus.client.exceptions import ConnectionPoolError, NotConnectError, VersionError
+from .exceptions import ConnectionPoolError, VersionError
 
-support_versions = ('0.9.x', '0.10.x')
+support_versions = ('0.11.x',)
 
 
 def _is_version_match(version):
     version_prefix = version.split(".")
     for support_version in support_versions:
         support_version_prefix = support_version.split(".")
-        if version_prefix[0] == support_version_prefix[0] and version_prefix[1] == support_version_prefix[1]:
+        if version_prefix[0] == support_version_prefix[0] \
+           and version_prefix[1] == support_version_prefix[1]:
             return True
     return False
 
@@ -62,7 +62,8 @@ class ConnectionRecord:
         self._kw = kwargs
 
         if handler == "GRPC":
-            self._connection = GrpcHandler(uri=uri, pre_ping=self._pre_ping, conn_id=conn_id, **self._kw)
+            self._connection = grpc_handler.GrpcHandler(uri=uri, pre_ping=self._pre_ping,
+                                                        conn_id=conn_id, **self._kw)
         elif handler == "HTTP":
             self._connection = HttpHandler(uri=uri, pre_ping=self._pre_ping)
         else:
@@ -77,6 +78,9 @@ class ConnectionRecord:
         #     self._connection.ping()
         return self._connection
 
+    def conn_id(self):
+        return self._conn_id
+
 
 class ConnectionPool:
     def __init__(self, uri, pool_size=10, wait_timeout=30, try_connect=True, **kwargs):
@@ -105,14 +109,11 @@ class ConnectionPool:
                 # LOGGER.debug("Try connect server {}".format(self._uri))
                 conn.client().ping()
 
-            status, version = conn.client().server_version(timeout=30)
-            if not status.OK():
-                raise NotConnectError("Cannot check server version: {}".format(status.message))
+            version = conn.client().server_version(timeout=30)
             if not _is_version_match(version):
                 raise VersionError(
-                    "Version of python SDK(v{}) not match that of server v{}, excepted is v{}".format(__version__,
-                                                                                                  version,
-                                                                                                  support_versions))
+                    "Version of python SDK(v{}) not match that of server v{}, "
+                    "excepted is v{}".format(__version__, version, support_versions))
         conn.close()
 
     def _inc_used(self):
@@ -231,9 +232,8 @@ class SingletonThreadPool:
         version = conn.client().server_version(timeout=30)
         if not _is_version_match(version):
             raise VersionError(
-                "Version of python SDK({}) not match that of server{}, excepted is {}".format(__version__,
-                                                                                              version,
-                                                                                              support_versions))
+                "Version of python SDK({}) not match that of server{}, "
+                "excepted is {}".format(__version__, version, support_versions))
 
     def record_duration(self, conn, duration):
         pass
@@ -278,14 +278,11 @@ class SingleConnectionPool:
             if self._try_connect:
                 self._conn.client().ping()
 
-            status, version = self._conn.client().server_version(timeout=30)
-            if not status.OK():
-                raise NotConnectError("Cannot check server version: {}".format(status.message))
+            version = self._conn.client().server_version(timeout=30)
             if not _is_version_match(version):
                 raise VersionError(
-                    "Version of python SDK({}) not match that of server{}, excepted is {}".format(__version__,
-                                                                                                  version,
-                                                                                                  support_versions))
+                    "Version of python SDK({}) not match that of server{}, "
+                    "excepted is {}".format(__version__, version, support_versions))
 
     def record_duration(self, conn, duration):
         pass
@@ -354,14 +351,14 @@ class ScopedConnection:
         return conn.connection()
 
     def conn_id(self):
-        return self._connection._conn_id
+        return self._connection.conn_id()
 
     def close(self):
         self._closed = True
         if not self._pool:
             return
 
-        self._connection and self._pool.release(self._connection)
+        _ = self._connection and self._pool.release(self._connection)
         self._connection = None
         if self._duration:
             self._duration.stop()
